import type { BPTreeNode, SerializeStrategyHead } from 'serializable-bptree';
import type { SupportedType, KlafDocumentRoot } from './KlafDocumentService';
import { SerializeStrategyAsync } from 'serializable-bptree';
import { KlafService } from '../core/KlafService';
import { KlafRepositorySynchronizer } from './KlafRepositorySynchronizer';
export type QueueNode = BPTreeNode<string, SupportedType> | KlafDocumentRoot;
export interface KlafStrategyConstructorArguments {
    property: string;
    order: number;
    service: KlafService;
    synchronizer: KlafRepositorySynchronizer<QueueNode>;
    rootId: string;
    root: KlafDocumentRoot;
    deleteQueue: Set<string>;
    updateQueue: Map<string, QueueNode>;
    tempNodes: Map<string, QueueNode>;
}
export declare class KlafStrategy extends SerializeStrategyAsync<string, SupportedType> {
    protected readonly property: string;
    protected readonly rootId: string;
    protected readonly service: KlafService;
    protected readonly synchronizer: KlafRepositorySynchronizer<QueueNode>;
    protected readonly root: KlafDocumentRoot;
    private _tempNodes;
    constructor({ property, order, service, synchronizer, rootId, root, tempNodes, }: KlafStrategyConstructorArguments);
    private _setHeadToRoot;
    private _getHeadInRoot;
    private _addOverflowRecord;
    private _readFromRepository;
    private _updateNode;
    private _deleteNode;
    id(): Promise<string>;
    read(id: string): Promise<BPTreeNode<string, SupportedType>>;
    write(id: string, node: BPTreeNode<string, SupportedType>): Promise<void>;
    delete(id: string): Promise<void>;
    readHead(): Promise<SerializeStrategyHead | null>;
    writeHead(head: SerializeStrategyHead): Promise<void>;
}
