export declare class Debounce {
    readonly delay: number;
    private _executing;
    private _timers;
    private _promises;
    private _pendingExecutions;
    private _currentExecutions;
    constructor(delay: number);
    /**
     * Executes a function after debouncing any previous calls with the same ID.
     * @param id The identifier for this execution group
     * @param execute The function to execute
     * @returns A promise that resolves with the result of the executed function
     */
    execute<T = any>(id: string, execute: () => Promise<T>): Promise<T>;
    /**
     * Cancels any pending execution with the given ID.
     * @param id The identifier for the execution group to cancel
     */
    cancel(id: string): void;
    /**
     * Checks if an execution with the given ID is currently running.
     * @param id The identifier to check
     * @returns True if the execution is running, false otherwise
     */
    isExecuting(id: string): boolean;
    /**
     * Checks if an execution with the given ID is currently being debounced.
     * @param id The identifier to check
     * @returns True if the execution is being debounced, false otherwise
     */
    isDebouncing(id: string): boolean;
    /**
     * Waits for any pending or executing function with the given ID to complete.
     * @param id The identifier to wait for
     * @returns A promise that resolves with the result of the executed function
     */
    done<T = any>(id: string): Promise<T | undefined>;
}
